<?php

/**
 * @file
 * Contains \Drupal\spectra_connect\Entity\Controller\SpectraConnectEntityListBuilder.
 */

namespace Drupal\spectra_connect\Entity\Controller;

use Drupal\Core\Entity\EntityInterface;
use Drupal\Core\Entity\EntityTypeInterface;
use Drupal\Core\Entity\EntityListBuilder;
use Drupal\Core\Entity\EntityStorageInterface;
use Drupal\Core\Routing\UrlGeneratorInterface;
use Symfony\Component\DependencyInjection\ContainerInterface;
use Drupal\spectra_connect\SpectraConnectUtilities;

/**
 * Provides a list controller for spectra_connect_entity entity.
 *
 * @ingroup spectra_connect
 */
class SpectraConnectEntityListBuilder extends EntityListBuilder {

  /**
   * The url generator.
   *
   * @var \Drupal\Core\Routing\UrlGeneratorInterface
   */
  protected $urlGenerator;


  /**
   * {@inheritdoc}
   */
  public static function createInstance(ContainerInterface $container, EntityTypeInterface $entity_type) {
    return new static(
      $entity_type,
      $container->get('entity.manager')->getStorage($entity_type->id()),
      $container->get('url_generator')
    );
  }

  /**
   * Constructs a new EntityStatementListBuilder object.
   *
   * @param \Drupal\Core\Entity\EntityTypeInterface $entity_type
   *   The entity type spectra_connect_entity.
   * @param \Drupal\Core\Entity\EntityStorageInterface $storage
   *   The entity storage class.
   * @param \Drupal\Core\Routing\UrlGeneratorInterface $url_generator
   *   The url generator.
   */
  public function __construct(EntityTypeInterface $entity_type, EntityStorageInterface $storage, UrlGeneratorInterface $url_generator) {
    parent::__construct($entity_type, $storage);
    $this->urlGenerator = $url_generator;
  }


  /**
   * {@inheritdoc}
   *
   * We override ::render() so that we can add our own content above the table.
   * parent::render() is where EntityListBuilder creates the table using our
   * buildHeader() and buildRow() implementations.
   */
  public function render() {
    $build['description'] = array(
      '#markup' => '',
    );
    $build['table'] = parent::render();

    return $build;
  }

  /**
   * {@inheritdoc}
   *
   * Building the header and content lines for the spectra_connect_entity list.
   *
   * Calling the parent::buildHeader() adds a column for the possible actions
   * and inserts the 'edit' and 'delete' links as defined for the entity type.
   */
  public function buildHeader() {
    $header['id'] = $this->t('Connector ID');
    $header['connector_name'] = $this->t('Connector Name');
    $header['plugin'] = $this->t('Spectra Plugin');
    $header['post_endpoint'] = $this->t('POST Endpoint');
    $header['get_endpoint'] = $this->t('GET Endpoint');
    return $header + parent::buildHeader();
  }

  /**
   * {@inheritdoc}
   */
  public function buildRow(EntityInterface $entity) {
    /* @var $entity \Drupal\spectra_connect\Entity\SpectraConnectEntity */
    $row['id'] = $entity->id();
    $form_keys = array('connector_name', 'plugin', 'post_endpoint', 'get_endpoint');
    foreach ($form_keys as $key) {
      switch ($key) {
        // Leaving this switch in case we need to add special handling later.
        default:
          $row[$key] = isset($entity->get($key)->getValue()[0]['value']) ? $entity->get($key)->getValue()[0]['value'] : '';
      }
    }
    return $row + parent::buildRow($entity);
  }

}
