<?php
/**
 * @file
 * Contains \Drupal\spectra_connect\Entity\SpectraConnectEntity.
 */

namespace Drupal\spectra_connect\Entity;

use Drupal\Core\Entity\EntityStorageInterface;
use Drupal\Core\Field\BaseFieldDefinition;
use Drupal\Core\Entity\ContentEntityBase;
use Drupal\Core\Entity\EntityTypeInterface;
use Drupal\user\UserInterface;
use Drupal\spectra_connect\Controller\SpectraConnectEntityController;
use Drupal\Core\Entity\EntityChangedTrait;

/**
 * Defines the SpectraConnectEntity entity.
 *
 * @ingroup spectra_connect
 *
 *
 * @ContentEntityType(
 * id = "spectra_connect_entity",
 * label = @Translation("Spectra Connect Entity"),
 * handlers = {
 *   "view_builder" = "Drupal\Core\Entity\EntityViewBuilder",
 *   "list_builder" = "Drupal\spectra_connect\Entity\Controller\SpectraConnectEntityListBuilder",
 *   "views_data" = "Drupal\spectra_connect\Entity\Views\SpectraConnectEntityViewsData",
 *   "form" = {
 *     "add" = "Drupal\spectra_connect\Form\SpectraConnectEntityForm",
 *     "edit" = "Drupal\spectra_connect\Form\SpectraConnectEntityForm",
 *     "delete" = "Drupal\spectra_connect\Form\SpectraConnectEntityDeleteForm",
 *   },
 *   "access" = "Drupal\spectra_connect\SpectraConnectEntityAccessControlHandler",
 * },
 * base_table = "spectra_connect_entity",
 * admin_permission = "administer spectra_connect",
 * fieldable = FALSE,
 * entity_keys = {
 *   "id" = "connect_id",
 *   "uuid" = "uuid",
 * },
 * links = {
 *   "canonical" = "/spectra_connect_entity/{spectra_connect_entity}",
 *   "edit-form" = "/spectra_connect_entity/{spectra_connect_entity}/edit",
 *   "delete-form" = "/spectra_connect_entity/{spectra_connect_entity}/delete",
 *   "collection" = "/spectra_connect_entity/list"
 * },
 * )
 */
class SpectraConnectEntity extends ContentEntityBase {

  use EntityChangedTrait;

  /**
   * {@inheritdoc}
   */
  public function getCreatedTime() {
    return $this->get('created')->value;
  }

  /**
   * {@inheritdoc}
   *
   * Define the field properties here.
   *
   * Field name, type and size determine the table structure.
   *
   * In addition, we can define how the field and its content can be manipulated
   * in the GUI. The behaviour of the widgets used can be determined here.
   */
  public static function baseFieldDefinitions(EntityTypeInterface $entity_type) {

    // Standard field, used as unique if primary index.
    $fields['connect_id'] = BaseFieldDefinition::create('integer')
      ->setLabel(t('ID'))
      ->setDescription(t('The ID of the SpectraConnectEntity entity.'))
      ->setReadOnly(TRUE);

    // Standard field, unique outside of the scope of the current project.
    $fields['uuid'] = BaseFieldDefinition::create('uuid')
      ->setLabel(t('UUID'))
      ->setDescription(t('The UUID of the SpectraConnectEntity entity.'))
      ->setReadOnly(TRUE);

    $fields['created'] = BaseFieldDefinition::create('created')
      ->setLabel(t('Created'))
      ->setDescription(t('The time that the entity was created.'));

    $fields['connector_name'] = BaseFieldDefinition::create('string')
      ->setLabel(t('Connector Name'))
      ->setDescription(t('A unique name for the connector.'))
      ->setSettings(array(
        'default_value' => 'default',
        'max_length' => 255,
        'text_processing' => 0,
      ));

    $fields['plugin'] = BaseFieldDefinition::create('string')
      ->setLabel(t('Spectra Plugin'))
      ->setDescription(t('The plugin to utilize.'))
      ->setSettings(array(
        'default_value' => 'default',
        'max_length' => 255,
        'text_processing' => 0,
      ));

    $fields['post_endpoint'] = BaseFieldDefinition::create('string')
      ->setLabel(t('Spectra POST Endpoint'))
      ->setDescription(t('The endpoint for sending POST requests.'))
      ->setSettings(array(
        'default_value' => 'default',
        'max_length' => 255,
        'text_processing' => 0,
      ));

    $fields['get_endpoint'] = BaseFieldDefinition::create('string')
      ->setLabel(t('Spectra GET Endpoint'))
      ->setDescription(t('The endpoint for sending GET requests.'))
      ->setSettings(array(
        'default_value' => 'default',
        'max_length' => 255,
        'text_processing' => 0,
      ));

    $fields['api_key'] = BaseFieldDefinition::create('string')
      ->setLabel(t('API Key'))
      ->setDescription(t('The API key for the connector. This must be generated at the server.'))
      ->setSettings(array(
        'default_value' => 'default',
        'max_length' => 255,
        'text_processing' => 0,
      ));

    return $fields;
  }
}