<?php

/**
 * @file
 * Contains \Drupal\spectra_connect\Form\SpectraConnectEntityDeleteForm.
 */

namespace Drupal\spectra_connect\Form;

use Drupal\Core\Entity\ContentEntityConfirmFormBase;
use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Url;

/**
 * Provides a form for deleting a spectra_connect_entity entity.
 *
 * @ingroup spectra_connect
 */
class SpectraConnectEntityDeleteForm extends ContentEntityConfirmFormBase {

    /**
     * {@inheritdoc}
     */
    public function getQuestion() {
        return $this->t('Are you sure you want to delete Spectra Connect Entity %name?', array('%name' => $this->entity->id()));
    }

    /**
     * {@inheritdoc}
     *
     * If the delete command is canceled, return to the contact list.
     */
    public function getCancelUrl() {
        return new Url('entity.spectra_connect_entity.collection');
    }

    /**
     * {@inheritdoc}
     */
    public function getConfirmText() {
        return $this->t('Delete');
    }

    /**
     * {@inheritdoc}
     *
     * Delete the entity and log the event. logger() replaces the watchdog.
     */
    public function submitForm(array &$form, FormStateInterface $form_state) {
        $entity = $this->getEntity();
        $entity->delete();

        $this->logger('spectra_connect')->notice('Deleted Spectra Connect Entity %title.',
            array(
                '%title' => $this->entity->id(),
            ));
        // Redirect to spectra_connect_entity list after delete.
        $form_state->setRedirect('entity.spectra_connect_entity.collection');
    }

}
