<?php
/**
 * @file
 * Contains \Drupal\spectra_connect\Form\SpectraConnectEntityForm.
 */

namespace Drupal\spectra_connect\Form;

use Drupal\Core\Entity\ContentEntityForm;
use Drupal\Core\Form\FormStateInterface;
use \Drupal\Component\Utility\Html;

/**
 * Form controller for the spectra_connect_entity entity edit forms.
 *
 * @ingroup spectra_connect
 */
class SpectraConnectEntityForm extends ContentEntityForm {

  /**
   * Build Bundle Type List
   */
  public function createEntityList() {
    $ret = array();
    foreach(\Drupal::entityTypeManager()->getDefinitions() as $type => $info) {
      // is this a content/front-facing entity?
      if ($info instanceof \Drupal\Core\Entity\ContentEntityType) {
        $label = $info->getLabel();
        if ($label instanceof \Drupal\Core\StringTranslation\TranslatableMarkup) {
          $label = $label->render();
        }
        $ret[$type] = $label;
      }
    }
    return $ret;
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    /* @var $entity \Drupal\spectra_connect\Entity\SpectraConnectEntity */
    $form = parent::buildForm($form, $form_state);
    $ent = $this->getEntity();
    $vals = [];
    $vals['connector_name'] = $ent->get('connector_name')->getValue();
    $vals['plugin'] = $ent->get('plugin')->getValue();
    $vals['post_endpoint'] = $ent->get('post_endpoint')->getValue();
    $vals['get_endpoint'] = $ent->get('get_endpoint')->getValue();
    $vals['api_key'] = $ent->get('api_key')->getValue();

    $form['connector_name'] = array(
      '#title' => t('Connector Name'),
      '#description' => t('The unique name of the connector'),
      '#type' => 'textfield',
      '#required' => TRUE,
      '#default_value' => isset($vals['connector_name'][0]['value']) ? $vals['connector_name'][0]['value'] : '',
    );

    $form['plugin'] = array(
      '#title' => t('Plugin'),
      '#description' => t('The Spectra plugin to use. Leave blank for the default.'),
      '#type' => 'textfield',
      '#required' => FALSE,
      '#default_value' => isset($vals['plugin'][0]['value']) ? $vals['plugin'][0]['value'] : '',
    );

    $form['post_endpoint'] = array(
      '#title' => t('Spectra POST Endpoint'),
      '#description' => t('The endpoint for sending POST requests.'),
      '#type' => 'textfield',
      '#required' => TRUE,
      '#default_value' => isset($vals['post_endpoint'][0]['value']) ? $vals['post_endpoint'][0]['value'] : '',
    );

    $form['get_endpoint'] = array(
      '#title' => t('Spectra GET Endpoint'),
      '#description' => t('The endpoint for sending GET requests.'),
      '#type' => 'textfield',
      '#required' => TRUE,
      '#default_value' => isset($vals['get_endpoint'][0]['value']) ? $vals['get_endpoint'][0]['value'] : '',
    );

    $form['api_key'] = array(
      '#title' => t('API Key'),
      '#description' => t('The API key for accessing the Spectra server. You will need to get a key from the server.'),
      '#type' => 'textfield',
      '#required' => TRUE,
      '#default_value' => isset($vals['api_key'][0]['value']) ? $vals['api_key'][0]['value'] : '',
    );

    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function save(array $form, FormStateInterface $form_state) {
    // Redirect to term list after save.
    $form_state->setRedirect('entity.spectra_connect_entity.collection');
    $vals = $form_state->getValues();
    $entity = $this->getEntity();
    $entity->set('connector_name', Html::escape($vals['connector_name']));
    $entity->set('plugin', Html::escape($vals['plugin']));
    $entity->set('post_endpoint', Html::escape($vals['post_endpoint']));
    $entity->set('get_endpoint', Html::escape($vals['get_endpoint']));
    $entity->set('api_key', Html::escape($vals['api_key']));
    $entity->save();
  }
}
