<?php

/**
 * @file
 * Contains \Drupal\spectra_connect\SpectraConnectEntityAccessControlHandler.
 */

namespace Drupal\spectra_connect;

use Drupal\Core\Access\AccessResult;
use Drupal\Core\Entity\EntityAccessControlHandler;
use Drupal\Core\Entity\EntityInterface;
use Drupal\Core\Session\AccountInterface;

/**
 * Access controller for the SpectraConnectEntity entity.
 *
 * @see \Drupal\spectra_connect\Entity\SpectraConnectEntity.
 */
class SpectraConnectEntityAccessControlHandler extends EntityAccessControlHandler {

    /**
     * {@inheritdoc}
     *
     * Link the activities to the permissions. checkAccess is called with the
     * $operation as defined in the routing.yml file.
     */
    protected function checkAccess(EntityInterface $entity, $operation, AccountInterface $account) {
        switch ($operation) {
            case 'view':
                return AccessResult::allowedIfHasPermission($account, 'administer spectra_connect');

            case 'edit':
                return AccessResult::allowedIfHasPermission($account, 'administer spectra_connect');

            case 'delete':
                return AccessResult::allowedIfHasPermission($account, 'administer spectra_connect');
        }
        return AccessResult::allowed();
    }

    /**
     * {@inheritdoc}
     *
     * Separate from the checkAccess because the entity does not yet exist, it
     * will be created during the 'add' process.
     */
    protected function checkCreateAccess(AccountInterface $account, array $context, $entity_bundle = NULL) {
        return AccessResult::allowedIfHasPermission($account, 'administer spectra_connect');
    }

}
